==> CDPKit-1.1.0.tar.gz: CDPKit-1.1.0/Libs/Python/CDPL/Vis/PointArray2DExport.cpp <==
/* 
 * PointArray2DExport.cpp 
 *
 * This file is part of the Chemical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#include <boost/python.hpp>

#include "CDPL/Vis/PointArray2D.hpp"
#include "CDPL/Vis/Rectangle2D.hpp"

#include "ClassExports.hpp"


void CDPLPythonVis::exportPointArray2D()
{
    using namespace boost;
    using namespace CDPL;

    python::class_<Vis::PointArray2D, python::bases<Math::Vector2DArray> >("PointArray2D", python::no_init)
        .def(python::init<>(python::arg("self")))    
        .def(python::init<const Vis::PointArray2D&>((python::arg("self"), python::arg("array"))))
        .def("translate", &Vis::PointArray2D::translate, (python::arg("self"), python::arg("vec")))
        .def("getBounds", &Vis::PointArray2D::getBounds, (python::arg("self"), python::arg("bbox")));
}

==> CDPKit-1.2.0.dev1.tar.gz: CDPKit-1.2.0.dev1/Libs/Python/CDPL/Vis/PointArray2DExport.cpp <==
/* 
 * PointArray2DExport.cpp 
 *
 * This file is part of the Chemical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#include <boost/python.hpp>

#include "CDPL/Vis/PointArray2D.hpp"
#include "CDPL/Vis/Rectangle2D.hpp"

#include "ClassExports.hpp"


void CDPLPythonVis::exportPointArray2D()
{
    using namespace boost;
    using namespace CDPL;

    python::class_<Vis::PointArray2D, Vis::PointArray2D::SharedPointer,
                   python::bases<Math::Vector2DArray> >("PointArray2D", python::no_init)
        .def(python::init<>(python::arg("self")))    
        .def(python::init<const Vis::PointArray2D&>((python::arg("self"), python::arg("array"))))
        .def("translate", &Vis::PointArray2D::translate, (python::arg("self"), python::arg("vec")))
        .def("getBounds", &Vis::PointArray2D::getBounds, (python::arg("self"), python::arg("bbox")));
}
